//
// RadioButtonEntry.cpp
// Implementation for TRadioButtonEntry class
//

#include <stdio.h>
#include <string>
#include "RadioButtonEntry.h"

enum {
	PMI_ABOUT = 'ham!'
};

//
// TRadioButtonEntry implementation
//
TComponent *TRadioButtonEntry::CreateComponent(BView *view, TFormDesigner *designer, BRect rect)
{
	TDesignRadioButton *btn = new TDesignRadioButton(rect, "RadioButton", "RadioButton", designer);
	btn->SetClassName(ClassName());
	
	view->LockLooper();
	view->AddChild(btn);
	view->UnlockLooper();
	return btn;
}

//
// TDesignRadioButton implementation
//
TDesignRadioButton::TDesignRadioButton(BRect frame, const char *name, const char *caption, TFormDesigner *designer)
:	BRadioButton(frame, name, caption, 0)
, TControlComponent(0, designer, ctVisual)
{
	SetComponentName(name);
	SetDTView(this); // ALWAYS do this
	InitPropertyList(); // and this
	InitPropertyValues();
	InitEventList();
	InitEventValues();
}

void TDesignRadioButton::MouseDown(BPoint pt)
{
	DesignerMouseDown(pt, Bounds(), this);
	Invalidate();
}

void TDesignRadioButton::Draw(BRect updateRect)
{
	BRadioButton::Draw(updateRect);
	DesignerDrawSelection();
}

const char *TDesignRadioButton::GetPropertyValue(const char *propName) const
{
	string s = propName;
	
	if(s == "Checked")
	{
		return Value() == B_CONTROL_ON ? "true" : "false";
	}
	
	return TControlComponent::GetPropertyValue(propName);
}

void TDesignRadioButton::SetPropertyValue(const char *propName, const char *value)
{
	printf("TDesignRadioButton::SetPropertyValue('%s', '%s')\n", propName, value);
	if((!propName) || (!value)) return;
	
	string s = propName;
	string v = value;
	
	if(s == "Checked")
	{
		if(LockLooper())
		{
			SetValue(v == "true"? B_CONTROL_ON : B_CONTROL_OFF);
			UnlockLooper();
		}
		StoreProperty(propName, value);
		return;
	}
	
	TControlComponent::SetPropertyValue(propName, value);
}

void TDesignRadioButton::InitPropertyList(void)
{
	TControlComponent::InitPropertyList();
	
	AddPropAndEditor(
		new TProperty(this, "Checked", "false")
	, new TBoolProperty(this, 0)
	);
}

void TDesignRadioButton::InitEventList(void)
{
	TControlComponent::InitEventList();
	
	AddEvent(new TEvent("OnChecked", "bool checked"));
}

void TDesignRadioButton::InitPropertyValues(void)
{
	TControlComponent::InitPropertyValues();
}

void TDesignRadioButton::InitEventValues(void)
{
	TControlComponent::InitEventValues();
}

void TDesignRadioButton::OnSetConstructorParams(BString &s)
{
	TControlComponent::OnSetConstructorParams(s);	
	
	char buf[256] = "";
	sprintf(
		buf
	, "\"%s\", 0"
	, GetPropertyValue("Label")
	);
	s += buf;
}

// eof
