//
// Form.h
//

#ifndef _Form_H
#define _Form_H

#include <View.h>
#include <Window.h>

class TForm;

//
// A form view
//
class TFormView: public BView {
public:
	TFormView(TForm *parent, const char *name);

	TForm *ParentForm(void) const { return m_ParentForm; }
private:
	TForm *m_ParentForm;
};

//
// A form
//
class TForm: public BWindow {
public:
  TForm(
  	BRect frame
  , const char *title
  , window_type type
  , uint32 flags
  , uint32 workspaces = B_CURRENT_WORKSPACE
	, bool bMainForm = false
  );
  
  TForm(
  	BRect frame
  , const char *title
  , window_look look
  , window_feel feel
  , uint32 flags
  , uint32 workspaces = B_CURRENT_WORKSPACE
	, bool bMainForm = false
  );  

	void MakeMainForm(bool b = true) { m_IsMainForm = b; }
	bool IsMainForm(void) const { return m_IsMainForm; }

  // BWindow overrides
  virtual void Show(void);
	virtual void Hide(void);
	virtual void Minimize(bool minimize);
	virtual void Zoom(BPoint origin, float width, float height);
	virtual void FrameMoved(BPoint origin);
	virtual void FrameResized(float width, float height);
	virtual void MenusBeginning(void);
	virtual void MenusEnded(void);
	virtual void ScreenChanged(BRect frame, color_space mode);
	virtual void Activate(bool activate = true);
	virtual void WindowActivated(bool active);
	virtual void WorkspaceActivated(int32 workspace, bool active);
	virtual void WorkspacesChanged(uint32 oldWorkspaces, uint32 newWorkspaces);
  virtual bool QuitRequested(void);
	
  // Events
  virtual void FormShow(void) {}
  virtual void FormHide(void) {}
  virtual void FormMinimize(void) {}
  virtual void FormZoom(void) {}

	TFormView *FormView(void) const { return m_FormView; }

protected:
	void SetFormView(TFormView *vw) { m_FormView = vw; }

private:
	TFormView *m_FormView;  
	bool m_IsMainForm;
};


#endif // _Form_H